==> forestry_1.7.10-3.6.0.577-unstable-dev.jar: forestry/core/network/PacketTileStream.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.core.network;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import net.minecraft.tileentity.TileEntity;

import forestry.core.proxy.Proxies;

public class PacketTileStream extends PacketCoordinates {

	private IStreamable streamable;

	public PacketTileStream(DataInputStream data) throws IOException {
		super(data);
	}

	public <T extends TileEntity & IStreamable> PacketTileStream(T streamable) {
		super(PacketId.TILE_FORESTRY_UPDATE, streamable);
		this.streamable = streamable;
	}

	@Override
	protected void writeData(DataOutputStream data) throws IOException {
		super.writeData(data);
		streamable.writeData(data);
	}

	@Override
	protected void readData(DataInputStream data) throws IOException {
		super.readData(data);

		TileEntity tile = getTarget(Proxies.common.getRenderWorld());
		if (tile instanceof IStreamable) {
			((IStreamable) tile).readData(data);
		}
	}
}

==> forestry_1.7.10-3.7.0.614-unstable-dev.jar: forestry/core/network/PacketTileStream.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.core.network;

import java.io.IOException;

import net.minecraft.tileentity.TileEntity;

import forestry.core.proxy.Proxies;

public class PacketTileStream extends PacketCoordinates {

	private IStreamable streamable;

	public static void onPacketData(DataInputStreamForestry data) throws IOException {
		new PacketTileStream(data);
	}

	public PacketTileStream(DataInputStreamForestry data) throws IOException {
		super(data);
	}

	public <T extends TileEntity & IStreamable> PacketTileStream(T streamable) {
		super(PacketId.TILE_FORESTRY_UPDATE, streamable);
		this.streamable = streamable;
	}

	@Override
	protected void writeData(DataOutputStreamForestry data) throws IOException {
		super.writeData(data);
		streamable.writeData(data);
	}

	@Override
	protected void readData(DataInputStreamForestry data) throws IOException {
		super.readData(data);

		TileEntity tile = getTarget(Proxies.common.getRenderWorld());
		if (tile instanceof IStreamable) {
			((IStreamable) tile).readData(data);
		}
	}
}
